// src/index.ts
import { visit } from "pre-visit";
function src_default(options = {}) {
  const { name = "class" } = options;
  const listName = `list-${name}`;
  return (root) => {
    visit(root, isDirective, (directive, parent, index, ancestors) => {
      if (parent) {
        if (directive.name === name) {
          if (directive.type === "containerDirective") {
            addHClasses(directive, directive.attributes.class);
          } else if (directive.type === "textDirective") {
            if (directive.children.length > 0) {
              setHName(directive, "span");
              addHClasses(directive, directive.attributes.class);
            } else {
              let node;
              if (index > 0 && (node = parent.children[index - 1]) && node.type !== "text" && node.position.end.column === directive.position.start.column) {
                addHClasses(node, directive.attributes.class);
              } else if (ancestors.length > 1 && ancestors[1].type === "listItem") {
                addHClasses(ancestors[1], directive.attributes.class);
              } else {
                addHClasses(parent, directive.attributes.class);
              }
              parent.children.splice(index, 1);
            }
          } else {
            if (directive.children.length > 0) {
              setHName(directive, "div");
              addHClasses(directive, directive.attributes.class);
            } else {
              addHClasses(parent, directive.attributes.class);
              parent.children.splice(index, 1);
            }
          }
        } else if (directive.name === listName && directive.type === "leafDirective") {
          const next = parent.children[index + 1];
          if (next?.type === "list") {
            addHClasses(next, directive.attributes.class);
            parent.children.splice(index, 1);
          }
        }
      }
    });
  };
}
function isDirective(node) {
  if (Object.keys(node).includes("type")) {
    const type = node.type;
    if (type === "containerDirective" || type === "leafDirective" || type === "textDirective") {
      return true;
    }
  }
  return false;
}
function getHProperties(node) {
  const data = node.data ?? (node.data = {});
  return data.hProperties ?? (data.hProperties = {});
}
function addHClasses(node, ...classes) {
  if (!classes || classes.length === 0)
    return;
  const hProperties = getHProperties(node);
  let existing = hProperties.class?.split(/\s/) ?? [];
  if (existing.length > 0) {
    classes = classes.filter((cls) => !existing.includes(cls));
    if (classes.length > 0) {
      hProperties.class += " " + classes.join(" ");
    }
  } else {
    hProperties.class = classes.join(" ");
  }
}
function setHName(node, name) {
  const data = node.data ?? (node.data = {});
  data.hName = name;
}
export {
  src_default as default
};
